The R package h0 provides a toolbox to conduct a Bayesian meta-analysis for estimating the current expansion rate of the Universe, called the Hubble constant H0, via time delay cosmography. The input data are (i) estimates of Fermat potential differences and their one-sigma uncertainties (standard errors), and (ii) estimates of time delays and their one-sigma uncertainties. Given these inputs, the meta-analysis draws a posterior sample of the model parameters including the Hubble constant.
Hyungsuk Tak
| Package: | h0 |
| Type: | Package |
| Version: | 1.0.1 |
| Date: | 2023-8-24 |
| License: | GPL-2 |
| Main functions: | h0 |
T. Treu and P. Marshall (2016) <doi:10.1007/s00159-016-0096-8> "Time Delay Cosmography".